@@ -979,7 +979,7 @@ ButtonRow * btn_buttonrow_copy(ButtonRow *src)
 */
 void btn_buttonrow_set_width(ButtonRow *brw, guint width)
 {
-	guint	i;
+	guint	i, j;
 
 	if((brw != NULL) && (width > 0))
 	{
@@ -995,7 +995,11 @@ void btn_buttonrow_set_width(ButtonRow *brw, guint width)
 		if(width > brw->width)		/* Growing? The init the new ones. */
 		{
 			for(i = brw->width; i < width; i++)
+			{
+				for(j = 0; j < sizeof brw->button[i].cmdseq / sizeof *brw->button[i].cmdseq; j++)
+					brw->button[i].cmdseq[j] = NULL;
 				btn_button_clear(brw->button + i);
+			}
 		}
 		brw->width = width;
 	}
