@@ -36,6 +36,8 @@ typedef struct {		/* External command general flags. */
 typedef struct {
 	GtkWidget	*hbox;
 	GtkWidget	*bframe;
+	GtkWidget	*reqsel_src;
+	GtkWidget	*reqsel_dst;
 	GtkWidget	*cdsrc;
 	GtkWidget	*cddst;
 	GtkWidget	*aframe;
@@ -326,6 +328,8 @@ static void set_cx_ba_flags(PXE_BAF *pxbaf, guint after, guint32 flags)
 	{
 		guint	st_src = FALSE, st_dst = FALSE;		/* Guess a few states. */
 
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->reqsel_src), flags & CBAF_REQSEL_SOURCE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->reqsel_dst), flags & CBAF_REQSEL_DEST);
 		if(flags & CBAF_CD_SOURCE)
 			st_src = TRUE;
 		else if(flags & CBAF_CD_DEST)
@@ -754,7 +758,6 @@ static gint evt_gf_clicked(GtkWidget *wid, gpointer user)
 		gtk_widget_set_sensitive(page->px_external.gflags.survive, page->curr_row->extra.external.gflags & CGF_RUNINBG);
 		set_repeat(page);
 	}
-
 	return TRUE;
 }
 
@@ -780,12 +783,39 @@ static void build_pxe_general(P_CmdSeq *page, PXE_General *pxg)
 	gtk_box_pack_start(GTK_BOX(hbox), pxg->survive, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(pxg->vbox), hbox, FALSE, FALSE, 0);
 
+/*	hbox = gtk_hbox_new(FALSE, 0);
+	pxg->reqsel_src = gtk_check_button_new_with_label(_("Require Source Selection?"));
+	gtk_object_set_user_data(GTK_OBJECT(pxg->reqsel_src), GINT_TO_POINTER(CGF_REQSEL_SRC));
+	gtk_signal_connect(GTK_OBJECT(pxg->reqsel_src), "clicked", GTK_SIGNAL_FUNC(evt_gf_clicked), page);
+	gtk_box_pack_start(GTK_BOX(hbox), pxg->reqsel_src, TRUE, TRUE, 0);
+	pxg->reqsel_dst = gtk_check_button_new_with_label(_("Require Destination Selection?"));
+	gtk_object_set_user_data(GTK_OBJECT(pxg->reqsel_dst), GINT_TO_POINTER(CGF_REQSEL_DST));
+	gtk_signal_connect(GTK_OBJECT(pxg->reqsel_dst), "clicked", GTK_SIGNAL_FUNC(evt_gf_clicked), page);
+	gtk_box_pack_start(GTK_BOX(hbox), pxg->reqsel_dst, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(pxg->vbox), hbox, FALSE, FALSE, 0);
+*/
 	pxg->graboutput = gtk_check_button_new_with_label(_("Capture Output?"));
 	gtk_object_set_user_data(GTK_OBJECT(pxg->graboutput), GINT_TO_POINTER(CGF_GRABOUTPUT));
 	gtk_signal_connect(GTK_OBJECT(pxg->graboutput), "clicked", GTK_SIGNAL_FUNC(evt_gf_clicked), page);
 	gtk_box_pack_start(GTK_BOX(pxg->vbox), pxg->graboutput, FALSE, FALSE, 0);
 }
 
+/* 2005-01-31 -	Handle clicks on source & destination selection requirement toggle buttons, and change flags. */
+static gint evt_baf_reqsel_clicked(GtkWidget *wid, gpointer user)
+{
+	P_CmdSeq	*page = user;
+	guint32		mask;
+
+	if((page == NULL) || (page->curr_seq == NULL) || (page->curr_row == NULL))
+		return TRUE;
+	mask = GPOINTER_TO_UINT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)))
+		page->curr_row->extra.external.baflags[0] |= mask;
+	else
+		page->curr_row->extra.external.baflags[0] &= ~mask;
+	return TRUE;
+}
+
 /* 1999-03-09 -	One of the CD check buttons was clicked. Do the pseudo-radio logic, and alter the
 **		flag setting of the current command row. Note that this is kind'a sneakily written
 **		(some would say ugly (uglily?)), since it actually relies on being called twice for
@@ -852,6 +882,16 @@ static void build_px_baf(P_CmdSeq *page, PXE_BAF *pxbaf)
 
 	pxbaf->bframe = gtk_frame_new(_("Before Execution"));
 	vbox = gtk_vbox_new(FALSE, 0);
+
+	pxbaf->reqsel_src = gtk_check_button_new_with_label(_("Require Source Selection?"));
+	gtk_object_set_user_data(GTK_OBJECT(pxbaf->reqsel_src), GINT_TO_POINTER(CBAF_REQSEL_SOURCE));
+	gtk_signal_connect(GTK_OBJECT(pxbaf->reqsel_src), "clicked", GTK_SIGNAL_FUNC(evt_baf_reqsel_clicked), page);
+	gtk_box_pack_start(GTK_BOX(vbox), pxbaf->reqsel_src, TRUE, TRUE, 0);
+	pxbaf->reqsel_dst = gtk_check_button_new_with_label(_("Require Destination Selection?"));
+	gtk_object_set_user_data(GTK_OBJECT(pxbaf->reqsel_dst), GINT_TO_POINTER(CBAF_REQSEL_DEST));
+	gtk_signal_connect(GTK_OBJECT(pxbaf->reqsel_dst), "clicked", GTK_SIGNAL_FUNC(evt_baf_reqsel_clicked), page);
+	gtk_box_pack_start(GTK_BOX(vbox), pxbaf->reqsel_dst, TRUE, TRUE, 0);
+	
 	pxbaf->cdsrc = gtk_check_button_new_with_label(_("CD Source?"));
 	gtk_signal_connect(GTK_OBJECT(pxbaf->cdsrc), "clicked", GTK_SIGNAL_FUNC(evt_baf_cd_clicked), page);
 	gtk_box_pack_start(GTK_BOX(vbox), pxbaf->cdsrc, TRUE, TRUE, 0);
