@@ -61,6 +61,8 @@ typedef struct {
 
 	GtkWidget	*cmccmd;		/* Entry widget for Click-M-Click command. */
 	GtkWidget	*cmcdelay;		/* HScale widget for cmc delay. */
+	
+	GtkWidget	*pathcmd;		/* Entry widget for path-rmb command. */
 
 	GtkWidget	*nonumlock;		/* Ignore numlock check button. */
 
@@ -142,6 +144,8 @@ static void reset_widgets(P_Controls *page)
 	cmd = ctrl_clickmclick_get_cmdseq(page->ctrlinfo);
 	gtk_entry_set_text(GTK_ENTRY(page->cmccmd), cmd ? cmd : "");
 	gtk_adjustment_set_value(gtk_range_get_adjustment(GTK_RANGE(page->cmcdelay)), ctrl_clickmclick_get_delay(page->ctrlinfo));
+	cmd = ctrl_general_get_cmdseq(page->ctrlinfo, CTRL_GENERAL_PATH_RMB);
+	gtk_entry_set_text(GTK_ENTRY(page->pathcmd), cmd ? cmd : "");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->nonumlock), ctrl_numlock_ignore_get(page->ctrlinfo));
 }
 
@@ -497,6 +501,35 @@ static void evt_clickmclick_delay_changed(GtkAdjustment *adj, gpointer user)
 
 /* ----------------------------------------------------------------------------------------- */
 
+/* 2004-04-25 -	Track editing of path-rmb command. */
+static void evt_pathcmd_changed(GtkWidget *wid, gpointer user)
+{
+	P_Controls	*page =  user;
+
+	if(page != NULL)
+	{
+		const gchar *text = gtk_entry_get_text(GTK_ENTRY(wid));
+
+		ctrl_general_set_cmdseq(page->ctrlinfo, CTRL_GENERAL_PATH_RMB, text);
+		page->modified = TRUE;
+	}
+}
+
+/* 2004-04-25 -	Help user pick a path-rmb command. */
+static void evt_pathcmd_pick_clicked(GtkWidget *wid, gpointer user)
+{
+	P_Controls	*page = user;
+
+	if(page != NULL)
+	{
+		const gchar *cmd = csq_dialog_sync_new_wait(page->min, ccs_get_current());
+		if(cmd != NULL)
+			gtk_entry_set_text(GTK_ENTRY(page->pathcmd), cmd);
+	}
+}
+
+/* ----------------------------------------------------------------------------------------- */
+
 /* 2000-02-18 -	User hit the "Ignore Num Lock?" toggle. Update editing state. */
 static void evt_nonumlock_clicked(GtkWidget *wid, gpointer user)
 {
@@ -654,6 +687,19 @@ static GtkWidget * cct_init(MainInfo *min, gchar **name)
 	gtk_box_pack_start(GTK_BOX(hbox), page->cmcdelay, TRUE, TRUE, 0);
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 	gtk_box_pack_start(GTK_BOX(page->vbox), frame, FALSE, FALSE, 0);
+
+	frame = gtk_frame_new(_("Path Right Click"));
+	hbox = gtk_hbox_new(FALSE, 0);
+	label = gtk_label_new(_("Command"));
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	page->pathcmd = gtk_entry_new();
+	gtk_signal_connect(GTK_OBJECT(page->pathcmd), "changed", GTK_SIGNAL_FUNC(evt_pathcmd_changed), page);
+	gtk_box_pack_start(GTK_BOX(hbox), page->pathcmd, TRUE, TRUE, 0);
+	wid = gui_details_button_new(page->min->gui->window->window);
+	gtk_signal_connect(GTK_OBJECT(wid), "clicked", GTK_SIGNAL_FUNC(evt_pathcmd_pick_clicked), page);
+	gtk_box_pack_start(GTK_BOX(hbox), wid, FALSE, FALSE, 0);
+	gtk_container_add(GTK_CONTAINER(frame), hbox);
+	gtk_box_pack_start(GTK_BOX(page->vbox), frame, FALSE, FALSE, 0);
 	
 	page->nonumlock = gtk_check_button_new_with_label(_("Ignore Num Lock For All Bindings?"));
 	gtk_signal_connect(GTK_OBJECT(page->nonumlock), "clicked", GTK_SIGNAL_FUNC(evt_nonumlock_clicked), page);
@@ -684,11 +730,13 @@ static void cct_accept(MainInfo *min)
 	if(page->modified)
 	{
 		if(ctrl_mouse_ambiguity_exists(page->ctrlinfo))
+		{
 			dlg_dialog_async_new_simple(_("Note: The mouse button control settings\n"
 						    "are ambiguous: the same button+modifier\n"
 						    "is used for more than one function. This\n"
 						    "might make their behaviour pretty weird..."),
 							_("Warning"), _("_OK"), NULL, NULL);
+		}
 		ctrl_destroy(min->cfg.ctrlinfo);
 		min->cfg.ctrlinfo = page->ctrlinfo;
 		page->ctrlinfo = NULL;
@@ -752,6 +800,28 @@ static void clickmclick_save(const CtrlInfo *ctrl, FILE *out)
 	xml_put_node_close(out, "ClickMClick");
 }
 
+/* 2004-04-25 -	Save general bindings. */
+static void general_save(const CtrlInfo *ctrl, FILE *out)
+{
+	GSList	*list;
+
+	if((list = ctrl_general_get_contexts(ctrl)) != NULL)	/* Only emit toplevel if there are bindings. */
+	{
+		const GSList	*iter;
+
+		xml_put_node_open(out, "Generals");
+		for(iter = list; iter != NULL; iter = g_slist_next(iter))
+		{
+			xml_put_node_open(out, "General");
+			xml_put_text(out, "context", (const gchar *) iter->data);
+			xml_put_text(out, "cmdseq", ctrl_general_get_cmdseq(ctrl, (const gchar *) iter->data));
+			xml_put_node_close(out, "General");
+		}
+		g_slist_free(list);
+	}
+	xml_put_node_close(out, "Generals");
+}
+
 /* 1999-03-17 -	Save the current control settings right out in given <file>. */
 static gint cct_save(MainInfo *min, FILE *out)
 {
@@ -759,6 +829,7 @@ static gint cct_save(MainInfo *min, FILE *out)
 	keys_save(min->cfg.ctrlinfo, out);
 	mouse_save(min->cfg.ctrlinfo, out);
 	clickmclick_save(min->cfg.ctrlinfo, out);
+	general_save(min->cfg.ctrlinfo, out);
 	xml_put_boolean(out, "ignore_numlock", ctrl_numlock_ignore_get(min->cfg.ctrlinfo));
 	xml_put_node_close(out, "Controls");
 
@@ -798,6 +869,21 @@ static void mousebuttons_load(MainInfo *min, const XmlNode *node)
 	xml_node_visit_children(node, mousebutton_load, min);
 }
 
+/* 2004-04-26 -	Load a general command binding. */
+static void general_load(const XmlNode *node, gpointer user)
+{
+	const gchar	*ctx, *cmd;
+
+	if(xml_get_text(node, "context", &ctx) && xml_get_text(node, "cmdseq", &cmd))
+		ctrl_general_set_cmdseq(((MainInfo *) user)->cfg.ctrlinfo, ctx, cmd);
+}
+
+/* 2004-04-26 -	Load a bunch of general command bindings. */
+static void generals_load(MainInfo *min, const XmlNode *node)
+{
+	xml_node_visit_children(node, general_load, min);
+}
+
 /* 1999-03-17 -	Load in the control config information. Replaces current. */
 static void cct_load(MainInfo *min, const XmlNode *node)
 {
@@ -821,13 +907,18 @@ static void cct_load(MainInfo *min, const XmlNode *node)
 		if((data = xml_tree_search(node, "ClickMClick")) != NULL)
 		{
 			const gchar	*cmd;
-			gfloat	delay;
+			gfloat		delay;
 			if(xml_get_text(data, "cmdseq", &cmd) && xml_get_real(data, "delay", &delay))
 			{
 				ctrl_clickmclick_set_cmdseq(min->cfg.ctrlinfo, cmd);
 				ctrl_clickmclick_set_delay(min->cfg.ctrlinfo, delay);
 			}
 		}
+		if((data = xml_tree_search(node, "Generals")) != NULL)
+		{
+			ctrl_general_clear(min->cfg.ctrlinfo);
+			generals_load(min, data);
+		}
 		if(xml_get_boolean(node, "ignore_numlock", &tmp))
 			ctrl_numlock_ignore_set(min->cfg.ctrlinfo, tmp);
 	}
