@@ -175,7 +175,7 @@ static gint evt_clicked(GtkWidget *wid, gpointer user)
 */
 static void build_frame(ChmInfo *ci, gint pos, gint type)
 {
-	gchar	*label[] = { N_("Special"), N_("Owner"),   N_("Group"),  N_("Other") };
+	gchar	*label[] = { N_("Special"), N_("Owner"),   N_("Group"),  N_("Others") };
 	gchar	*check[] = { N_("Set UID"), N_("Set GID"), N_("Sticky"), N_("Read"), N_("Write"), N_("Execute") };
 	PFrame	*fr = &ci->frame[pos];
 	gint	i;
