@@ -151,7 +151,8 @@ static gboolean do_delete_dir(MainInfo *min, const gchar *path, gboolean progres
 
 	if(rmdir(path) == 0)					/* If it's empty, this saves time. */
 		return 1;
-	else if((errno == ENOTEMPTY) || (errno == EEXIST))	/* Wasn't empty. Enter and traverse. */
+	else if((errno == ENOTEMPTY) || (errno == EEXIST) ||	/* Wasn't empty. Enter and traverse. */
+		(errno == EACCES))				/* Samba seems to somehow report non-empty with EACCES. Weird. */ /*bront bront, does this live?*/
 	{
 		err_clear(min);					/* Error was expected, so ignore it. */
 		if(fut_cd(path, old_dir, sizeof old_dir))
