@@ -24,6 +24,8 @@
 #include "cmd_parent.h"
 #include "cmd_direnter.h"
 
+#define	CMD_ID	"direnter"
+
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-05-07 -	Get the name of the first selected row of <dp>. If that is not a directory,
@@ -105,7 +107,7 @@ gint cmd_direnter(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		fam_monitor(src);
 		if(errno != 0)
 		{
-			err_set(min, errno, "DirEnter", buf);
+			err_set(min, errno, CMD_ID, buf);
 			err_show(min);
 		}
 	}
