@@ -12,6 +12,8 @@
 
 #include "cmd_dirrescan.h"
 
+#define	CMD_ID	"dirrescan"
+
 /* ----------------------------------------------------------------------------------------- */
 
 /* 2002-07-19 -	Rescan source directory. */
@@ -22,7 +24,7 @@ gint cmd_dirrescan(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	dp_show_stats(src);
 	if(errno)
 	{
-		err_set(min, errno, "DirRescan", src->dir.path);
+		err_set(min, errno, CMD_ID, src->dir.path);
 		err_show(min);
 	}
 	return errno == 0;
