@@ -11,6 +11,7 @@
 
 #include "cmd_copy.h"
 #include "cmd_delete.h"
+#include "dialog.h"
 #include "dirpane.h"
 #include "errors.h"
 #include "fileutil.h"
@@ -68,6 +69,24 @@ gboolean move_dir(MainInfo *min, const gchar *from, const gchar *to)
 	gchar		old_dir[PATH_MAX];
 	gchar		dest[PATH_MAX];
 
+	/* Do safety checking before removing existing destination directory. Bad if nested. */
+	if(fut_is_parent_of(from, to))
+	{
+		gchar	ebuf[2 * PATH_MAX + 128];
+
+		g_snprintf(ebuf, sizeof ebuf, _("Can't move directory \"%s\"\nto \"%s\":\nthe source contains the destination."), from, to);
+		dlg_dialog_async_new_error(ebuf);
+		return FALSE;
+	}
+	if(fut_is_parent_of(to, from))
+	{
+		gchar	ebuf[2 * PATH_MAX + 128];
+
+		g_snprintf(ebuf, sizeof ebuf, _("Can't move directory \"%s\"\nto \"%s\":\nthe destination contains the source."), from, to);
+		dlg_dialog_async_new_error(ebuf);
+		return FALSE;
+	}
+
 	/* Investigate toplevel overwrite status. */
 	switch(ovw_overwrite_file(min, to, from))
 	{
@@ -88,6 +107,11 @@ gboolean move_dir(MainInfo *min, const gchar *from, const gchar *to)
 	/* Try a quick rename. */
 	if(rename(from, to) == 0)
 		return TRUE;
+	else if(errno != EXDEV)
+	{
+		err_set(min, errno, CMD_ID, from);
+		return FALSE;
+	}
 
 	/* Get stat, enter and move all items, recursively. */
 	if(lstat(from, &stat) != 0)
@@ -172,7 +196,7 @@ gint cmd_move(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	dp_rescan_post_cmd(src);
 	dp_rescan_post_cmd(dst);
 	if(errno && iter != NULL)
-		err_set(min, errno, "move", dp_full_name(src, DP_SEL_INDEX(src, iter)));
+		err_set(min, errno, CMD_ID, dp_full_name(src, DP_SEL_INDEX(src, iter)));
 	pgs_progress_end(min);
 	ovw_overwrite_end(min);
 	fut_cd(old_path, NULL, 0);
