@@ -52,10 +52,7 @@ static void mva_body(MainInfo *min, DirPane *src, DirRow *row, gpointer user)
 static gint mva_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, gpointer user)
 {
 	gchar		dest[PATH_MAX], *text;
-	const gchar	*name;
 	MvaInfo		*mva = user;
-	mode_t		mode;
-	OvwRes		ores;
 	gboolean	ret = FALSE;
 
 	if(!fut_cd(src->dir.path, NULL, 0))
