@@ -22,6 +22,7 @@ gint cmd_parent(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
 	gchar	*ptr;
 	GString	*comp;
+	gint	ret = 0;
 
 	ptr = src->dir.path + strlen(src->dir.path) - 1;
 
@@ -44,10 +45,10 @@ gint cmd_parent(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 			g_string_truncate(comp, ptr - src->dir.path);
 			if(*comp->str == '\0')
 				g_string_assign(comp, "/");
-			csq_execute_format(min, "DirEnter 'dir=%s'", stu_escape(comp->str));
+			ret = csq_execute_format(min, "DirEnter 'dir=%s'", stu_escape(comp->str));
 			break;
 		}
 	}
 	g_string_free(comp, TRUE);
-	return 0;
+	return ret;
 }
