@@ -50,6 +50,12 @@ typedef struct {
 	GtkWidget	*re_to;
 	GtkWidget	*re_cnocase;
 
+	/* Mapping mode (for character substitutions). */
+	GtkWidget	*map_vbox;
+	GtkWidget	*map_from;
+	GtkWidget	*map_to;
+	GtkWidget	*map_remove;
+
 	MainInfo	*min;
 	DirPane		*src;
 	gint		page;
@@ -247,6 +253,87 @@ static gint rename_regexp(RenREInfo *ri)
 
 /* ----------------------------------------------------------------------------------------- */
 
+static int rename_map(RenREInfo *ri)
+{
+	const char	*fromdef, *todef, *remdef, *p;
+	GSList		*iter;
+	GString		*nn;
+	gint		err = 0;
+	gsize		fl, tl, rl, i, j;
+
+	if((fromdef = gtk_entry_get_text(GTK_ENTRY(ri->map_from))) == NULL)
+		return -1;
+	if((todef = gtk_entry_get_text(GTK_ENTRY(ri->map_to))) == NULL)
+		return -1;
+	if(strchr(todef, G_DIR_SEPARATOR) != NULL)	/* As always, prevent rogue moves. */
+		return -1;
+	if((remdef = gtk_entry_get_text(GTK_ENTRY(ri->map_remove))) == NULL)
+		return -1;
+
+	fl = strlen(fromdef);
+	tl = strlen(todef);
+	rl = strlen(remdef);
+
+	ovw_overwrite_begin(ri->min, _("\"%s\" Already Exists - Proceed With Rename?"), 0U);
+	nn = g_string_new("");
+	for(iter = ri->selection; iter != NULL; iter = g_slist_next(iter))
+	{
+		/* Step 1: set the dynamic string to the input filename. */
+		g_string_assign(nn, DP_SEL_NAME(iter));
+		/* Step 2: perform character mapping, as needed. */
+		for(i = 0; i < nn->len; i++)
+		{
+			if((p = strchr(fromdef, nn->str[i])) != NULL)
+			{
+				j = p - fromdef;
+				if(j < tl)
+					nn->str[i] = todef[j];
+			}
+		}
+		/* Step 3: remove any characters found in the 'remove' string. */
+		for(i = 0; i < nn->len;)
+		{
+			if(strchr(remdef, nn->str[i]) != NULL)
+				g_string_erase(nn, i, 1);
+			else
+				i++;
+		}
+		if(strcmp(DP_SEL_NAME(iter), nn->str) != 0)
+		{
+			OvwRes	ores;
+
+			ores = ovw_overwrite_file(ri->min, nn->str, NULL);
+			if(ores == OVW_SKIP)
+				continue;
+			else if(ores == OVW_CANCEL)
+				break;
+			else if(ores == OVW_PROCEED_FILE)
+			{
+				if(!del_delete_file(ri->min, nn->str))
+					break;
+			}
+			else if(ores == OVW_PROCEED_DIR)
+			{
+				if(!del_delete_dir(ri->min, nn->str, FALSE))
+					break;
+			}
+			if(rename(DP_SEL_NAME(iter), nn->str) != 0)
+			{
+				err = errno;
+				dp_rescan_post_cmd(ri->src);
+				err_set(ri->min, err, CMD_ID, DP_SEL_NAME(iter));
+			}
+			else
+				dp_unselect(ri->src, DP_SEL_INDEX(ri->src, iter));
+		}
+	}
+	g_string_free(nn, TRUE);
+	ovw_overwrite_end(ri->min);
+	return err;
+}
+
+/* ----------------------------------------------------------------------------------------- */
+
 static void evt_nbook_switchpage(GtkWidget *wid, GtkNotebookPage *page, gint page_num, gpointer user)
 {
 	RenREInfo	*ri = user;
@@ -271,6 +358,7 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		ri.nbook = gtk_notebook_new();
 		gtk_signal_connect(GTK_OBJECT(ri.nbook), "switch-page", GTK_SIGNAL_FUNC(evt_nbook_switchpage), &ri);
 
+		/* Build the 'Simple' mode's GUI. */
 		ri.r_vbox = gtk_vbox_new(FALSE, 0);
 		label = gtk_label_new(_("Look for substring in all filenames, and replace\nit with another string."));
 		gtk_box_pack_start(GTK_BOX(ri.r_vbox), label, FALSE, FALSE, 0);
@@ -293,7 +381,7 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 
 		gtk_notebook_append_page(GTK_NOTEBOOK(ri.nbook), ri.r_vbox, gtk_label_new(_("Simple")));
 
-
+		/* Build the 'Reg Exp' mode's GUI. */
 		ri.re_vbox = gtk_vbox_new(FALSE, 0);
 		label = gtk_label_new(	_("Execute the 'From' RE on each filename, storing\n"
 					"parenthesised subexpression matches. Then replace\n"
@@ -318,6 +406,30 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		gtk_notebook_append_page(GTK_NOTEBOOK(ri.nbook), ri.re_vbox, gtk_label_new(_("Reg Exp")));
 		gtk_widget_show_all(ri.re_vbox);
 
+		/* Build the 'Map' mode's GUI. */
+		ri.map_vbox = gtk_vbox_new(FALSE, 0);
+		label = gtk_label_new(_("Look for each character in the 'From' string, and replace\n"
+					"any hits with the corresponding character in the 'To' string.\n"
+					"Then, any characters in the 'Remove' string are removed from\n"
+					"the filename, and the result used as the new name for each file."));
+		gtk_box_pack_start(GTK_BOX(ri.map_vbox), label, FALSE, FALSE, 0);
+		table = gtk_table_new(3, 2, FALSE);
+		label = gtk_label_new(_("From"));
+		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
+		ri.map_from = gtk_entry_new();
+		gtk_table_attach(GTK_TABLE(table), ri.map_from, 1, 2, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
+		label = gtk_label_new(_("To"));
+		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
+		ri.map_to = gtk_entry_new();
+		gtk_table_attach(GTK_TABLE(table), ri.map_to, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
+		label = gtk_label_new(_("Remove"));
+		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,  0,0,0,0);
+		ri.map_remove = gtk_entry_new();
+		gtk_table_attach(GTK_TABLE(table), ri.map_remove, 1, 2, 2, 3,  GTK_EXPAND|GTK_FILL,0,0,0);
+		gtk_box_pack_start(GTK_BOX(ri.map_vbox), table, FALSE, FALSE, 0);
+
+		gtk_notebook_append_page(GTK_NOTEBOOK(ri.nbook), ri.map_vbox, gtk_label_new(_("Map")));
+
 		ri.dlg = dlg_dialog_sync_new(ri.nbook, _("RenameRE"), NULL);
 
 		ri.page = 0;
@@ -335,8 +447,10 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		{
 			if(ri.page == 0)
 				err = rename_simple(&ri);
-			else
+			else if(ri.page == 1)
 				err = rename_regexp(&ri);
+			else
+				err = rename_map(&ri);
 			fut_cd(old, NULL, 0U);
 		}
 		else
