@@ -19,7 +19,7 @@
 /* 1998-09-27 -	Pop up a dialog letting user select (or type) a command name,
 **		and then run it.
 */
-int cmd_run(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
+gint cmd_run(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
 	const gchar	*cmd;
 
