@@ -151,7 +151,7 @@ static gint size_split(SplitInfo *spi, DirPane *src, DirPane *dst, DirRow *row)
 	ovw_overwrite_end(spi->min);
 
 	if(errno)
-		err_set(spi->min, errno, "Split", spi->name);
+		err_set(spi->min, errno, CMD_ID, spi->name);
 	
 	return to_go == 0;
 }
