@@ -253,11 +253,13 @@ static gint build_input_string(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 	{
 		if((end = strchr(def + 2, '"')) != NULL)
 		{
-			GString	*dstr;
+			GString	*tmp, *dstr;
 
 			*end = '\0';
+			tmp = g_string_new(def + 2);
 			dstr = g_string_new("");
-			parse_code(dlg->min, dstr, def + 2, dlg, FALSE);
+			parse_code(dlg->min, dstr, tmp->str, dlg, FALSE);
+			g_string_free(tmp, TRUE);
 			gtk_entry_set_text(GTK_ENTRY(ent), dstr->str);
 			gtk_entry_select_region(GTK_ENTRY(ent), 0, -1);
 			g_string_free(dstr, TRUE);
@@ -411,7 +413,7 @@ static gint build_input_checkbox(CmdDlg *dlg, const gchar *label, const gchar *d
 static void parse_code_input(MainInfo *min, GString *cstr, gchar *code, CmdDlg *dlg)
 {
 	gchar		*ltxt = NULL, *end;
-	const gchar	*def = code + 1;
+	gchar		*def = code + 1;
 	gint		succ = 0;
 	GtkWidget	*label;
 
@@ -579,7 +581,7 @@ static void destroy_input(CmdDlg *dlg)
 /* ----------------------------------------------------------------------------------------- */
 
 /* 2003-11-16 -	Get ending brace for a code definition. Knows about embedded braces, unlike strchr(). */
-static gchar * get_code_end(gchar *def)
+static const gchar * get_code_end(const gchar *def)
 {
 	const gchar	*base = def;
 	gint		level;
@@ -626,7 +628,7 @@ static void parse_code(MainInfo *min, GString *cstr, gchar *code, CmdDlg *dlg, g
 			gchar	*end;
 
 			code++;
-			if((end = get_code_end(code)) != NULL)
+			if((end = (gchar *) get_code_end(code)) != NULL)
 			{
 				*end = '\0';		/* This is in a GString, so OK. */
 				if(code[0] == 'f' || code[0] == 'F')
