@@ -376,18 +376,12 @@ gboolean csq_handle_ba_flags(MainInfo *min, guint32 flags)
 	if(flags & CBAF_REQSEL_SOURCE)
 	{
 		if(!dp_has_selection(src))
-		{
-			printf("no source sel, failing\n");
 			return FALSE;
-		}
 	}
 	if(flags & CBAF_REQSEL_DEST)
 	{
 		if(!dp_has_selection(dst))
-		{
-			printf("no dest sel, failing\n");
 			return FALSE;
-		}
 	}
 
 	if(flags & CBAF_CD_SOURCE)
