@@ -606,7 +606,7 @@ static GtkWidget * field_build(CmdCfg *cmc, CField *fld, gpointer instance, GtkW
 					gint	i, current = *(gint *) ((gchar *) instance + fld->offset);
 
 					vbox = gtk_vbox_new(FALSE, 0);
-					group = gui_radio_group_new(fld->field.fenum.num, fld->field.fenum.label, radio);
+					group = gui_radio_group_new(fld->field.fenum.num, (const gchar **) fld->field.fenum.label, radio);
 					for(i = 0; i < fld->field.fenum.num; i++)
 					{
 						set_object_data(GTK_OBJECT(radio[i]), fld, instance);
