@@ -28,7 +28,9 @@ struct CtrlInfo {
 	struct {
 	GString		*cmdseq;		/* Command assigned to Click-M-Click action gesture. */
 	gfloat		delay;			/* Max delay in seconds to trigger cmc. */
-	}			clickmclick;
+	}		clickmclick;
+
+	GHashTable	*general;		/* General bindings. */
 };
 
 struct CtrlKey {
@@ -42,6 +44,13 @@ struct CtrlMouse {
 	GString	*cmdseq;		/* The command we run when triggerec. */
 };
 
+#define	CONTEXT_NAME_SIZE	(32)
+
+typedef struct {
+	gchar	context[CONTEXT_NAME_SIZE];
+	GString	*cmdseq;
+} CtrlGen;
+
 /* ----------------------------------------------------------------------------------------- */
 
 static CtrlKey *	key_new(const gchar *keyname, const gchar *cmdseq);
@@ -65,6 +74,8 @@ CtrlInfo * ctrl_new(MainInfo *min)
 	ctrl->clickmclick.cmdseq = NULL;
 	ctrl->clickmclick.delay  = 0.400f;
 
+	ctrl->general = NULL;
+
 	return ctrl;
 }
 
@@ -94,6 +105,8 @@ CtrlInfo * ctrl_new_default(MainInfo *min)
 	ctrl_mouse_add(ctrl, 2, 0U, "DirParent");
 	ctrl_mouse_add(ctrl, 3, 0U, "MenuPopup");
 
+	ctrl_general_set_cmdseq(ctrl, CTRL_GENERAL_PATH_RMB, "MenuPopup menu=<ParentsMenu>");
+
 	return ctrl;
 }
 
@@ -105,7 +118,7 @@ static gboolean key_remove(gpointer key, gpointer value, gpointer user)
 } 
 
 /* 1999-03-16 -	Copy a key. A callback for ctrl_copy() below. */
-static void copy_key(gpointer key, gpointer value, gpointer user)
+static void key_copy(gpointer key, gpointer value, gpointer user)
 {
 	if(((CtrlKey *) value)->cmdseq != NULL)
 		ctrl_key_add(user, ((CtrlKey *) value)->keyname, ((CtrlKey *) value)->cmdseq->str);
@@ -120,13 +133,34 @@ static void mouse_remove(gpointer data, gpointer user)
 }
 
 /* 1999-06-13 -	Copy a mouse button command mapping. */
-static void copy_mouse(gpointer data, gpointer user)
+static void mouse_copy(gpointer data, gpointer user)
 {
 	CtrlMouse	*cm = data;
 
 	ctrl_mouse_add(user, ctrl_mouse_get_button(cm), ctrl_mouse_get_state(cm), ctrl_mouse_get_cmdseq(cm));
 }
 
+/* 2004-04-25 -	Copy a general binding. */
+static void general_copy(gpointer key, gpointer value, gpointer user)
+{
+	if(value != NULL && ((CtrlGen *) value)->cmdseq != NULL)	/* Don't copy NULL cmdseq. */
+		ctrl_general_set_cmdseq(user, key, ((CtrlGen *) value)->cmdseq->str);
+}
+
+/* 2004-04-25 -	Remove a general binding. */
+static gboolean general_remove(gpointer key, gpointer value, gpointer user)
+{
+	CtrlGen	*cg = value;
+
+	if(cg != NULL)
+	{
+		if(cg->cmdseq != NULL)
+			g_string_free(cg->cmdseq, TRUE);
+		g_free(cg);
+	}
+	return TRUE;
+}
+
 /* 1999-03-16 -	Copy the entire control info structure. Very useful for config. Note that
 **		the copy will NOT retain the installation status of the original; in fact,
 **		it will not be installed anywhere (which is generally what you (should) want).
@@ -138,10 +172,11 @@ CtrlInfo * ctrl_copy(CtrlInfo *ctrl)
 	if(ctrl != NULL)
 	{
 		copy = ctrl_new(ctrl->min);
-		g_hash_table_foreach(ctrl->keys, copy_key, copy);
-		g_list_foreach(ctrl->mouse, copy_mouse, copy);
+		g_hash_table_foreach(ctrl->keys, key_copy, copy);
+		g_list_foreach(ctrl->mouse, mouse_copy, copy);
 		ctrl_clickmclick_set_cmdseq(copy, ctrl_clickmclick_get_cmdseq(ctrl));
 		ctrl_clickmclick_set_delay(copy,  ctrl_clickmclick_get_delay(ctrl));
+		g_hash_table_foreach(ctrl->general, general_copy, copy);
 		ctrl_numlock_ignore_set(copy, ctrl_numlock_ignore_get(ctrl));
 	}
 	return copy;
@@ -158,6 +193,8 @@ void ctrl_destroy(CtrlInfo *ctrl)
 		g_list_foreach(ctrl->mouse, mouse_remove, NULL);
 		if(ctrl->clickmclick.cmdseq)
 			g_string_free(ctrl->clickmclick.cmdseq, TRUE);
+		g_hash_table_foreach_remove(ctrl->general, general_remove, NULL);
+		g_hash_table_destroy(ctrl->general);
 		g_free(ctrl);
 	}
 }
@@ -637,6 +674,8 @@ gboolean ctrl_mouse_ambiguity_exists(const CtrlInfo *ctrl)
 	return FALSE;
 }
 
+/* ----------------------------------------------------------------------------------------- */
+
 void ctrl_clickmclick_set_cmdseq(CtrlInfo *ctrl, const gchar *cmdseq)
 {
 	if(cmdseq)
@@ -668,3 +707,65 @@ gfloat ctrl_clickmclick_get_delay(const CtrlInfo *ctrl)
 	return ctrl ? ctrl->clickmclick.delay : 0.0f;
 }
 
+/* ----------------------------------------------------------------------------------------- */
+
+/* 2004-04-26 -	Clear away all general command definitions. */
+void ctrl_general_clear(CtrlInfo *ctrl)
+{
+	if(ctrl == NULL || ctrl->general == NULL)
+		return;
+	g_hash_table_foreach_remove(ctrl->general, general_remove, NULL);
+}
+
+/* 2004-04-19 -	Store a new general command sequence. */
+void ctrl_general_set_cmdseq(CtrlInfo *ctrl, const gchar *context, const gchar *cmdseq)
+{
+	CtrlGen	*cg;
+
+	if(ctrl == NULL)
+		return;
+	if(ctrl->general == NULL)
+		ctrl->general = g_hash_table_new(g_str_hash, g_str_equal);
+	cg = g_hash_table_lookup(ctrl->general, context);
+	if(cg == NULL)
+	{
+		cg = g_malloc(sizeof *cg);
+		g_snprintf(cg->context, sizeof cg->context, "%s", context);
+		cg->cmdseq = g_string_new("");
+		g_hash_table_insert(ctrl->general, cg->context, cg);
+	}
+	if(cmdseq != NULL)
+		g_string_assign(cg->cmdseq, cmdseq);
+	else
+		general_remove(cg->context, cg, ctrl);
+}
+
+static void general_prepend(gpointer key, gpointer data, gpointer user)
+{
+	GSList	**list = user;
+
+	*list = g_slist_prepend(*list, key);
+}
+
+/* 2004-04-25 -	Return list of contexts, i.e. char pointers. They are constants. */
+GSList * ctrl_general_get_contexts(const CtrlInfo *ctrl)
+{
+	GSList	*list = NULL;
+
+	if(ctrl != NULL && ctrl->general != NULL)
+		g_hash_table_foreach(ctrl->general, general_prepend, &list);
+	return list;
+}
+
+/* 2004-04-19 -	Retrieve general command sequence. */
+const gchar * ctrl_general_get_cmdseq(const CtrlInfo *ctrl, const gchar *context)
+{
+	const CtrlGen	*cg;
+
+	if(ctrl == NULL || ctrl->general == NULL)
+		return NULL;
+	cg = g_hash_table_lookup(ctrl->general, context);
+	if(cg == NULL)
+		return NULL;
+	return cg->cmdseq != NULL ? cg->cmdseq->str : NULL;
+}
