@@ -189,7 +189,10 @@ static void dhentry_realpath_set(DHEntry *dhe, const gchar *realpath)
 /* 1999-06-09 -	Update <dhe> to mimic state of <dp>. */
 static void dhentry_update(DHEntry *dhe, const DirPane *dp)
 {
-	dhe->sel  = dirsel_set(dhe->sel, dp);
+	if(dp->main->cfg.dp_history.select)
+		dhe->sel  = dirsel_set(dhe->sel, dp);
+	else
+		dhe->sel = NULL;
 	dhe->vpos = dph_vpos_get(dp);
 	if(dp->focus_row != -1)
 		dhe->focus_row = dp->focus_row;
@@ -251,8 +254,8 @@ static DHSel * dirsel_set(DHSel *sel, const DirPane *dp)
 
 	if((slist = dp_get_selection_full(dp)) != NULL)
 	{
-		HKey		*key;
 		const GSList	*iter;
+		HKey		*key;
 
 		if(sel == NULL)
 			sel = dirsel_new();
