@@ -35,6 +35,7 @@
 #include "fileutil.h"
 #include "gfam.h"
 #include "guiutil.h"
+#include "miscutil.h"
 #include "mount.h"
 #include "sizeutil.h"
 #include "strutil.h"
@@ -344,6 +345,21 @@ static gboolean evt_path_key_press(GtkWidget *wid, GdkEventKey *evt, gpointer us
 	return FALSE;
 }
 
+/* 2004-04-18 -	Mouse click in path entry widget. */
+static gboolean evt_path_button_press(GtkWidget *wid, GdkEventButton *evt, gpointer user)
+{
+	if(evt->type == GDK_BUTTON_PRESS && evt->button == 3)
+	{
+		DirPane		*dp = user;
+		const gchar	*cmd;
+
+		if((cmd = ctrl_general_get_cmdseq(dp->main->cfg.ctrlinfo, CTRL_GENERAL_PATH_RMB)) != NULL)
+			csq_execute(dp->main, cmd);
+		return TRUE;
+	}
+	return FALSE;
+}
+
 /* 1998-05-27 -	I had forgotten about the possibility for users to click in the path entry widget, and
 **		by doing so circumventing my clever (hairy) flag system. This remedies that.
 ** 1998-05-29 -	Changed polarity of operation. Was broken. Sloppy me.
@@ -580,6 +596,9 @@ static gboolean evt_dirpane_button_press_early(GtkWidget *wid, GdkEventButton *e
 	DirPane		*dp = user;
 	GTimeVal	now;
 
+	/* This added in an attempt to solve weird path-entry-eats-focus problem. Feels bad. */
+	gtk_widget_grab_focus(GTK_WIDGET(dp->main->gui->top));
+
 	/* Handle commands mapped to mouse buttons. This includes the RMB menu, typically. */
 	if((event->type == GDK_BUTTON_PRESS) && (mcmd = ctrl_mouse_map(dp->main->cfg.ctrlinfo, event)) != NULL)
 	{
@@ -599,7 +618,7 @@ static gboolean evt_dirpane_button_press_early(GtkWidget *wid, GdkEventButton *e
 		const gchar *cmd = ctrl_clickmclick_get_cmdseq(dp->main->cfg.ctrlinfo);
 		if(cmd && *cmd)
 		{
-			gfloat	elapsed = 1E-6f * (now.tv_usec - last_time.tv_usec) + (now.tv_sec - last_time.tv_sec);
+			gfloat	elapsed = msu_diff_timeval(&last_time, &now);
 			if(elapsed < ctrl_clickmclick_get_delay(dp->main->cfg.ctrlinfo))
 			{
 				csq_execute(dp->main, cmd);
@@ -1171,7 +1190,7 @@ static gint idle_activate(gpointer data)
 
 /* 2002-07-13 -	Activate a pane, but queue the rendering until GTK+ is idle. This works around
 **		a very annoying bug/misfeature which causes "ghost" pane scrolling to occur.
-**		We only queue the rendering, since that seems to suffice, and we need to really
+**		We only queue the rendering, since that seems to suffice, but we need to really
 **		change gentoo's idea of "active pane" immediately or things break.
 */
 static void dp_activate_queued(DirPane *dp)
@@ -1706,6 +1725,7 @@ GtkWidget * dp_build(MainInfo *min, DPFormat *fmt, DirPane *dp)
 	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(dp->path)->entry),  "focus_in_event", GTK_SIGNAL_FUNC(evt_path_focus), dp);
 	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(dp->path)->entry),  "focus_out_event", GTK_SIGNAL_FUNC(evt_path_unfocus), dp);
 	dp->complete.change_sig = gtk_signal_connect(GTK_OBJECT(GTK_COMBO(dp->path)->entry), "changed", GTK_SIGNAL_FUNC(evt_path_changed), dp);
+	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(dp->path)->entry), "button_press_event", GTK_SIGNAL_FUNC(evt_path_button_press), dp);
 	gtk_box_pack_start(GTK_BOX(hbox), dp->path, TRUE, TRUE, 0);
 	gtk_tooltips_set_tip(min->gui->main_tt, GTK_COMBO(dp->path)->entry, _("Enter path, then press Return to go there"), NULL);
 	dp->hide = gtk_toggle_button_new_with_label(_("H"));
