@@ -824,11 +824,14 @@ void fut_free_path(GList *list)
 **		for empty files, a return value of 0 indicates success.
 ** 2000-07-16 -	Bug fix: the interruption check was done after the write(), so small files
 **		that fit into the chunk_size could not be interrupted. Oops.
+** 2006-01-06 -	When writing across a SMB mount, write() seems to dislike large chunks, so
+**		we need to do the write()s multiple times for each read(). Odd.
 */
 off_t fut_copy(gint in, gint out, gsize chunk_size)
 {
 	gpointer	buf;
-	gssize		got, wrote;
+	gconstpointer	wbuf;
+	gssize		got, wrote, to_write;
 	off_t		put = 0U;
 
 	if((in < 0) || (out < 0))
@@ -844,11 +847,17 @@ off_t fut_copy(gint in, gint out, gsize chunk_size)
 			errno = EINTR;
 			break;
 		}
-		wrote = write(out, buf, got);
-		if(wrote < 0)
-			break;
-		put += wrote;
+		for(to_write = got, wbuf = buf; to_write > 0; to_write -= wrote, wbuf += wrote, put += wrote)
+		{
+			wrote = write(out, wbuf, to_write);
+			if(wrote < 0)
+			{
+				fprintf(stderr, "gentoo: fut_copy() failed to write %d-byte block, errno=%d--aborting copy\n", got, errno);
+				goto fail;
+			}
+		}
 	}
+fail:
 	g_free(buf);
 
 	return put;
