@@ -462,7 +462,7 @@ int main(int argc, char *argv[])
 		OPT_NORC = 1 << 3, OPT_NOGTKRC = 1 << 4, OPT_NOFAM = 1 << 5 };
 	OptDesc	od[] = { { '\0', "version",  OPT_ARG_NONE, OPT_VERSION,	N_("Report the version to standard output, and exit.") },
 #if defined ENABLE_NLS
-			 { '\0', "locale-info", OPT_ARG_NONE, OPT_LOCALEINFO, N_("Reports internal locale details, and exits.") },
+			 { '\0', "locale-info", OPT_ARG_NONE, OPT_LOCALEINFO, N_("Report internal locale details, and exit.") },
 #endif
 			 { '\0', "root-ok",  OPT_ARG_NONE, OPT_ROOTOK,	N_("Allows gentoo to be run by the root user. Could be dangerous.") },
 			 { '\0', "no-rc",    OPT_ARG_NONE, OPT_NORC,	N_("Do not load the ~/.gentoorc configuration file; instead, use default values.") },
