@@ -85,6 +85,7 @@
 
 #if defined ENABLE_NLS
 #include <locale.h>
+#include <langinfo.h>
 /* These two are used to mark translatable strings in the source code.
 ** _() is used in contexts where C allows a function call, N_() where
 ** it does not. Strings marked with N_() still need to be passed to _()
@@ -272,6 +273,8 @@ typedef struct {
 #define	CBAF_RESCAN_DEST	(1<<1)
 #define	CBAF_CD_SOURCE		(1<<2)		/* These save some config work. */
 #define	CBAF_CD_DEST		(1<<3)
+#define	CBAF_REQSEL_SOURCE	(1<<4)		/* Command won't run if there's no source selection when envoked. */
+#define	CBAF_REQSEL_DEST	(1<<5)		/* Command won't run if there's no destination selection when envoked. */
 
 typedef struct {		/* Extra info for external commands. */
 	guint32	gflags;			/* General flags. */
