@@ -17,8 +17,8 @@
 
 #include <stdlib.h>
 
-#include "strutil.h"
 #include "fileutil.h"
+#include "strutil.h"
 #include "iconutil.h"
 
 /* ----------------------------------------------------------------------------------------- */
@@ -53,7 +53,7 @@ typedef struct {
 /* 1998-08-15 -	IconGfx comparison function for hash table. */
 static gint cmp_icon(gconstpointer a, gconstpointer b)
 {
-	return strcmp(((IconGfx *) a)->name, ((IconGfx *) b)->name) == 0;
+	return strcmp(((const IconGfx *) a)->name, ((const IconGfx *) b)->name) == 0;
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -103,7 +103,7 @@ GList * ico_get_all(MainInfo *min, const gchar *path)
 
 	if(path != NULL)
 	{
-		list = fut_scan_path(path, icon_filter, FALSE);
+		list = fut_scan_path(path, icon_filter);
 		if((head = g_strdup(ICON_NONE)) != NULL)
 			list = g_list_prepend(list, head);
 	}
@@ -163,17 +163,17 @@ static GdkPixmap * get_or_load(IconInfo *ico, const gchar *name, GdkBitmap **mas
 	IconGfx	*ig;
 
 	if(ico->icon == NULL)
-		ico->icon = g_hash_table_new(g_str_hash, (GCompareFunc) cmp_icon);
+		ico->icon = g_hash_table_new(g_str_hash, cmp_icon);
 	if(ico->icon != NULL)
 	{
-		if((ig = (IconGfx *) g_hash_table_lookup(ico->icon, (gpointer) name)) != NULL)
+		if((ig = g_hash_table_lookup(ico->icon, name)) != NULL)
 		{
 			*mask = ig->mask;
 			return ig->pixmap;
 		}
 		else if((ig = load(ico, name)) != NULL)
 		{
-			g_hash_table_insert(ico->icon, (gpointer) ig->name, (gpointer) ig);
+			g_hash_table_insert(ico->icon, ig->name, ig);
 			*mask = ig->mask;
 			return ig->pixmap;
 		}
@@ -211,7 +211,7 @@ GdkPixmap * ico_icon_get(MainInfo *min, const gchar *name, GdkBitmap **mask)
 */
 static gboolean kill_icon(gpointer key, gpointer value, gpointer user)
 {
-	IconGfx	*icon = (IconGfx *) value;
+	IconGfx	*icon = value;
 
 	gdk_pixmap_unref(icon->pixmap);
 	gdk_bitmap_unref(icon->mask);
