@@ -4,10 +4,11 @@
 */
 
 #include "gentoo.h"
-#include "cmdseq.h"
 
+#include "cmdseq.h"
 #include "dialog.h"
 #include "dirpane.h"
+#include "fileutil.h"
 #include "strutil.h"
 
 #include "menus.h"
@@ -74,6 +75,7 @@ struct MenuInfo {
 
 static void	menu_build_action(MainInfo *min, GtkWidget *wid);
 static void	menu_build_time(MainInfo *min, GtkWidget *wid);
+static void	menu_build_parents(MainInfo *min, GtkWidget *wid);
 
 static GHashTable	*dynamic_hash = NULL;
 
@@ -82,7 +84,9 @@ static GHashTable	*dynamic_hash = NULL;
 void mnu_initialize(void)
 {
 	static const DynMenu	dyn_menu[] = {  { "<ActionMenu>",	menu_build_action },
-						{ "<TimeMenu>",		menu_build_time } };
+						{ "<TimeMenu>",		menu_build_time },
+						{ "<ParentsMenu>",	menu_build_parents }
+	};
 	guint			i;
 
 	dynamic_hash = g_hash_table_new(g_str_hash, g_str_equal);
@@ -298,6 +302,47 @@ static void menu_build_time(MainInfo *min, GtkWidget *menu)
 	gtk_widget_show(item);
 }
 
+/* 2004-04-18 -	User picked an item from the <ParentsMenu> menu. Go there. */
+static void evt_menu_parents_activate(GtkWidget *wid, gpointer user)
+{
+	gchar	*text = NULL;
+
+	if(!GTK_IS_MENU_ITEM(wid))
+		return;
+	wid = GTK_BIN(wid)->child;
+	if(!GTK_IS_LABEL(wid))
+		return;
+	gtk_label_get(GTK_LABEL(wid), &text);
+	if(text != NULL)
+		csq_execute_format(user, "DirEnter 'dir=%s'", stu_escape(text));
+}
+
+/* 2004-04-18 -	Build menu containing parent directories of current pane's dir. */
+static void menu_build_parents(MainInfo *min, GtkWidget *menu)
+{
+	const DirPane	*dp = min->gui->cur_pane;
+	gchar		canon[PATH_MAX], *sep;
+	GtkWidget	*item;
+
+	if(dp == NULL)
+		return;
+	fut_path_canonicalize(dp->dir.path, canon, sizeof canon);
+	while((sep = strrchr(canon, G_DIR_SEPARATOR)) != NULL)
+	{
+		*sep = '\0';
+		if(canon[0] == '\0')
+			break;
+		item = gtk_menu_item_new_with_label(canon);
+		gtk_signal_connect(GTK_OBJECT(item), "activate", GTK_SIGNAL_FUNC(evt_menu_parents_activate), min);
+		gtk_menu_append(GTK_MENU(menu), item);
+	}
+	/* Always append a root ("/") item, since the root has itself as its parent. Avoids empty menu, as bonus. */
+	item = gtk_menu_item_new_with_label("/");
+	gtk_signal_connect(GTK_OBJECT(item), "activate", GTK_SIGNAL_FUNC(evt_menu_parents_activate), min);
+	gtk_menu_append(GTK_MENU(menu), item);
+	gtk_widget_show_all(menu);
+}
+
 /* ----------------------------------------------------------------------------------------- */
 
 /* The standard callback for a menu item; just run the attached command. */
