@@ -63,8 +63,8 @@ static void get_info(MainInfo *min, gchar *buf, gsize buf_size, const gchar *old
 	{
 		strftime(o_date, sizeof o_date, min->cfg.opt_overwrite.datefmt, localtime(&o_st.st_ctime));
 		strftime(n_date, sizeof n_date, min->cfg.opt_overwrite.datefmt, localtime(&n_st.st_ctime));
-		g_snprintf(buf, buf_size, _("\nOld: %Lu bytes, changed on %s.\n"
-						   "New: %Lu bytes, changed on %s."),
+		g_snprintf(buf, buf_size, _("\nOld: %llu bytes, changed on %s.\n"
+						   "New: %llu bytes, changed on %s."),
 						   o_st.st_size, o_date,
 						   n_st.st_size, n_date);
 	}
