@@ -4,8 +4,10 @@
 
 enum { OVWF_NO_RECURSE_TEST = 1 << 0 };
 
-typedef enum { OVW_SKIP, OVW_PROCEED, OVW_CANCEL } OvwRes;
+typedef enum { OVW_SKIP, OVW_PROCEED, OVW_PROCEED_FILE, OVW_PROCEED_DIR, OVW_CANCEL } OvwRes;
 
 extern void	ovw_overwrite_begin(MainInfo *min, const gchar *desc, guint32 flags);
 extern OvwRes	ovw_overwrite_file(MainInfo *min, const gchar *old_file, const gchar *new_file);
 extern void	ovw_overwrite_end(MainInfo *min);
+
+extern gboolean	ovw_overwrite_parent(const MainInfo *min, const gchar *old_file, const gchar *new_file);
