@@ -281,9 +281,9 @@ void stl_styleinfo_dump(StyleInfo *si)
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-05-19 -	Get the GNode that holds the given <stl>. */
-static GNode * styleinfo_style_get_node(StyleInfo *si, Style *stl)
+static GNode * styleinfo_style_get_node(const StyleInfo *si, const Style *stl)
 {
-	return g_node_find(si->styles, G_PRE_ORDER, G_TRAVERSE_ALL, stl);
+	return g_node_find(si->styles, G_PRE_ORDER, G_TRAVERSE_ALL, (gpointer) stl);
 }
 
 /* 1999-05-20 -	Find the sibling of <parent> that should come next after <node>,
@@ -974,7 +974,7 @@ const gchar * stl_style_get_name(Style *stl)
 }
 
 /* 1999-06-12 -	Get the branch that begins with the root style and ends with <stl>. */
-static GSList * style_get_branch(Style *stl)
+static GSList * style_get_branch(const Style *stl)
 {
 	GNode	*node;
 
