@@ -291,7 +291,7 @@ static gint evt_keypress(GtkWidget *wid, GdkEventKey *evt, gpointer user)
 {
 	TxvInfo	*txi = gtk_object_get_user_data(GTK_OBJECT(wid));
 
-	if(evt->keyval == GDK_Escape)
+	if(evt->keyval == GDK_Escape || evt->keyval == GDK_Left)
 		really_destroy(wid);
 	else if(evt->keyval == GDK_End)
 	{
