@@ -579,6 +579,7 @@ void win_window_set_title(GtkWidget *win, const gchar *title)
 #if defined ENABLE_NLS
 	gchar		obuf[256];	/* Buffer, subsequent setlocale() call kills it otherwise. */
 	const gchar	*op;
+	int		old_errno = errno;	/* Buffer the errno, so any errors here don't leak out. */
 
 	/* Get current locale, before slamming "C" in there. */
 	if((op = setlocale(LC_ALL, NULL)) != NULL)
@@ -596,6 +597,7 @@ void win_window_set_title(GtkWidget *win, const gchar *title)
 #if defined ENABLE_NLS
 	if(op != NULL)
 		setlocale(LC_ALL, obuf);
+	errno = old_errno;	/* Restore the errno, ignoring any errors that might have happened here. */
 #endif
 }
 
