@@ -263,7 +263,7 @@ static void put_string(FILE *out, const gchar *str)
 	gchar	here;
 	gint	i;
 
-	for(; (here = *str) != '\0'; str++)
+	for(; str && (here = *str) != '\0'; str++)
 	{
 		for(i = 0; i < NUM_ESC_SEQ; i++)
 		{
